<?php
/**
 * bizhunt functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package bizhunt
 */

if ( ! function_exists( 'bizhunt_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function bizhunt_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on bizhunt, use a find and replace
		 * to change 'bizhunt' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'bizhunt', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		// Add thumbnail sizes
		add_image_size( 'bizhunt_work_360_280', 360, 280, true );
		add_image_size( 'bizhunt_brands_180_75', 180, 75, true );
		add_image_size( 'bizhunt_team_265_210', 265, 210, true );
		add_image_size('bizhunt_work_360_245',360,243,true);
		

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'header' => esc_html__( 'Primary', 'bizhunt' ),
			'footer' => esc_html__( 'Footer', 'bizhunt' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'bizhunt_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'bizhunt_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bizhunt_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'bizhunt_content_width', 640 );
}
add_action( 'after_setup_theme', 'bizhunt_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function bizhunt_widgets_init() {
	global $bizhunt_options;
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'bizhunt' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'bizhunt' ),
		'before_widget' => '<div class="single-widget">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1', 'bizhunt' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'bizhunt' ),
		'before_widget' => '<div class="col-md-3 col-sm-6 col-xs-12">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2', 'bizhunt' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'bizhunt' ),
		'before_widget' => '<div class="col-md-3 col-sm-6 col-xs-12">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3', 'bizhunt' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'bizhunt' ),
		'before_widget' => '<div class="col-md-3 col-sm-6 col-xs-12">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 4', 'bizhunt' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Add widgets here.', 'bizhunt' ),
		'before_widget' => '<div class="col-md-3 col-sm-6 col-xs-12">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

}
add_action( 'widgets_init', 'bizhunt_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function bizhunt_scripts() {
	
	wp_enqueue_style( 'bizhunt-font', bizhunt_fonts_url() );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
	wp_enqueue_style( 'bootstrap-theme', get_template_directory_uri() . '/assets/css/bootstrap-theme.min.css' );
	wp_enqueue_style( 'bizhunt-font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css' );
	wp_enqueue_style( 'carousel', get_template_directory_uri() . '/assets/css/owl.carousel.min.css' );
	wp_enqueue_style( 'owl-theme', get_template_directory_uri() . '/assets/css/owl.theme.default.min.css' );
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.min.css' );
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.css' );
	wp_enqueue_style( 'slicknav', get_template_directory_uri() . '/assets/css/slicknav.min.css' );
	wp_enqueue_style( 'normalize', get_template_directory_uri() . '/assets/css/normalize.css' );
	wp_enqueue_style( 'bizhunt-style', get_template_directory_uri() . '/assets/css/style.css' );
	wp_enqueue_style( 'bizhunt-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );

	wp_enqueue_script( 'navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(''), '20151215', true );
	wp_enqueue_script( 'skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(''), '20151215', true );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), '3.3.7', true );
	wp_enqueue_script( 'jquery-nav', get_template_directory_uri() . '/assets/js/jquery.nav.js', array('jquery'), '3.0.0', true );
	wp_enqueue_script( 'scrollUp', get_template_directory_uri() . '/assets/js/jquery.scrollUp.min.js', array('jquery'), '2.4.1', true );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array('jquery'), '2.3.0', true );
	wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/assets/js/waypoints.min.js', array('jquery'), '1.6.2', true );
	wp_enqueue_script( 'counterup', get_template_directory_uri() . '/assets/js/jquery.counterup.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', array('jquery'), '3.0.4', true );
	wp_enqueue_script( 'stellar', get_template_directory_uri() . '/assets/js/jquery.stellar.min.js', array('jquery'), '0.6.2', true );
	wp_enqueue_script( 'wow-min', get_template_directory_uri() . '/assets/js/wow.min.js', array('jquery'), '1.1.3', true );
	wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/jquery.magnific-popup.min.js', array('jquery'), '1.1.0', true );
	wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/assets/js/jquery.slicknav.min.js', array('jquery'), '1.0.10', true );
	wp_enqueue_script( 'bizhunt-main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '1.1', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'bizhunt_scripts' );

/**
 * Load Breadcrumb
 */
require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * Load menu
 */
require get_template_directory() . '/inc/wp-bootstrap-navwalker.php';
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/helper.php';

/**
 * Load Breadcrumb
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Custom widgets
 */
require get_template_directory() . '/inc/widgets.php';



function bizhunt_pagination( $echo = true ) {
	$links = paginate_links( array(
		'prev_next'          => false,
		'type'               => 'array'
	) );

	if ( $links ) :

		echo '<ul class="pagination-nav list-inline">';

    	// get_previous_posts_link will return a string or void if no link is set.
		if ( $prev_posts_link = get_previous_posts_link( __( '<i class="fa fa-angle-left"></i>','bizhunt' ) ) ) :
			echo '<li>';
			echo $prev_posts_link;
			echo '</li>';
		endif;

		echo '<li>';
		echo join( '</li><li>', $links );
		echo '</li>';

    	// get_next_posts_link will return a string or void if no link is set.
		if ( $next_posts_link = get_next_posts_link( __( '<i class="fa fa-angle-right"></i>','bizhunt' ) ) ) :
			echo '<li class="next-list-item">';
			echo $next_posts_link;
			echo '</li>';
		endif;
		echo '</ul>';
	endif;
}


if ( is_admin() ) {
	// Load about.
	
	require_once trailingslashit( get_template_directory() ) . 'inc/theme-info/class-about.php';
	require_once trailingslashit( get_template_directory() ) . 'inc/theme-info/about.php';

	// Load demo.
	require_once trailingslashit( get_template_directory() ) . 'inc/demo/class-demo.php';
	require_once trailingslashit( get_template_directory() ) . 'inc/demo/demo.php';
}