<?php
/**
 * bizhunt Theme Customizer
 *
 * @package bizhunt
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function bizhunt_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

// Sanitization Callback
	require_once trailingslashit( get_template_directory() ) . '/inc/sanitize.php'; 

	// Sanitization Callback
	require_once trailingslashit( get_template_directory() ) . '/inc/customizer-front.php'; 

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'bizhunt_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'bizhunt_customize_partial_blogdescription',
		) );
	}

	//Upgrade to Pro
	// Register custom section types.
	$wp_customize->register_section_type( 'Bizhunt_Customize_Section_Upsell' );

	// Register sections.
	$wp_customize->add_section(
		new Bizhunt_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell',
			array(
				'title'    => esc_html__( 'Go Pro', 'bizhunt' ),
				'pro_text' => esc_html__( 'Buy Bizhunt Pro', 'bizhunt' ),
				'pro_url'  => 'https://justwpthemes.com/downloads/bizhunt-pro/',
				'priority' => 1,
			)
		)
	);
}
add_action( 'customize_register', 'bizhunt_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function bizhunt_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function bizhunt_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function bizhunt_customize_preview_js() {
	wp_enqueue_script( 'bizhunt-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'bizhunt_customize_preview_js' );


/**
 * Enqueue required scripts/styles for customizer panel
 *
 * @since 1.0.0
 */
function bizhunt_customize_backend_scripts() {
	wp_enqueue_script( 'bizhunt-customize-controls', get_template_directory_uri() . '/inc/upgrade-to-pro/pro.js', array( 'customize-controls' ) );
	wp_enqueue_style( 'bizhunt-customize-controls', get_template_directory_uri() . '/inc/upgrade-to-pro/pro.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'bizhunt_customize_backend_scripts', 10 );

require_once trailingslashit( get_template_directory() ) . '/inc/upgrade-to-pro/control.php';
